@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import asyncio
 from dataclasses import dataclass
-from typing import ClassVar, List, Tuple
+from typing import ClassVar, List, Tuple, Optional
 
 from yarl import URL
 
@@ -14,6 +14,7 @@ class MediaItem:
     complete: bool
     filename: str
     ext: str
+    original_filename: str
 
     async def is_complete(self):
         return self.complete
