@@ -3,8 +3,8 @@ from __future__ import annotations
 import asyncio
 import logging
 import multiprocessing
-from base64 import b64encode
 from functools import wraps
+from http import HTTPStatus
 from random import gauss
 
 import aiofiles
@@ -13,20 +13,34 @@ from rich.live import Live
 from rich.progress import TaskID
 from yarl import URL
 
-from .progress_definitions import get_forum_table, cascade_progress, domain_progress, album_progress, file_progress, \
-    forum_progress, get_cascade_table, overall_file_progress
-from cyberdrop_dl.base_functions.base_functions import log, logger, check_free_space, allowed_filetype, get_db_path, \
-    clear
+from cyberdrop_dl.base_functions.base_functions import (
+    clear,
+    get_db_path,
+    log,
+    logger,
+)
+from cyberdrop_dl.base_functions.data_classes import AlbumItem, CascadeItem, DomainItem, FileLock, ForumItem, MediaItem
 from cyberdrop_dl.base_functions.error_classes import DownloadFailure
 from cyberdrop_dl.base_functions.sql_helper import SQLHelper
-from cyberdrop_dl.base_functions.data_classes import AlbumItem, CascadeItem, FileLock, ForumItem, DomainItem, MediaItem
 from cyberdrop_dl.client.client import Client, DownloadSession
 from cyberdrop_dl.scraper.Scraper import ScrapeMapper
 
-
-async def basic_auth(username, password):
-    token = b64encode(f"{username}:{password}".encode('utf-8')).decode("ascii")
-    return f'Basic {token}'
+from .downloader_utils import (
+    allowed_filetype,
+    basic_auth,
+    check_free_space,
+    is_4xx_client_error,
+)
+from .progress_definitions import (
+    album_progress,
+    cascade_progress,
+    domain_progress,
+    file_progress,
+    forum_progress,
+    get_cascade_table,
+    get_forum_table,
+    overall_file_progress,
+)
 
 
 def retry(f):
@@ -139,6 +153,8 @@ class Downloader:
 
     async def start_file(self, album_task: TaskID, album: str, media: MediaItem):
         """Handler for files and the progress bars for it"""
+        media.original_filename = media.filename
+
         if media.complete:
             await log(f"Previously Downloaded: {media.filename}", quiet=True)
             overall_file_progress.advance(self.files.skipped_files_task_id, 1)
@@ -179,7 +195,7 @@ class Downloader:
         if self.block_sub_folders:
             album = album.split('/')[0]
 
-        original_filename = media.filename
+        original_filename = media.original_filename
 
         try:
             while await self.File_Lock.check_lock(original_filename):
@@ -241,6 +257,7 @@ class Downloader:
 
             if fake_download:
                 overall_file_progress.advance(self.files.skipped_files_task_id, 1)
+                await log(f"Already Downloaded: {media.filename} from {media.referer}", quiet=True)
                 self.files.skipped_files += 1
             else:
                 overall_file_progress.advance(self.files.completed_files_task_id, 1)
@@ -270,7 +287,7 @@ class Downloader:
             new_error.message = repr(e)
 
             if hasattr(e, "code"):
-                if 400 <= e.code < 500 and e.code != 429:
+                if await is_4xx_client_error(e.code) and e.code != HTTPStatus.TOO_MANY_REQUESTS:
                     logger.debug("We ran into a 400 level error: %s", str(e.code))
                     await log(f"Failed Download: {media.filename}", quiet=True)
                     overall_file_progress.advance(self.files.failed_files_task_id, 1)
@@ -279,7 +296,7 @@ class Downloader:
                         self.current_attempt.pop(url_path)
                     await self.output_failed(media, e)
                     return
-                if e.code == 503:
+                if e.code == HTTPStatus.SERVICE_UNAVAILABLE:
                     if hasattr(e, "message"):
                         logging.debug(f"\n{media.url} ({e.message})")
                     await log(f"Failed Download: {media.filename}", quiet=True)
@@ -317,16 +334,20 @@ class Downloader:
                 downloaded_filename = await self.SQL_Helper.get_downloaded_filename(url_path, original_filename)
                 if downloaded_filename:
                     if media.filename == downloaded_filename:
-                        if complete_file.exists():
-                            proceed = False
-                            break
-                        elif partial_file.exists():
+                        if partial_file.exists():
                             if partial_file.stat().st_size == expected_size:
                                 proceed = False
                                 partial_file.rename(complete_file)
                                 break
                             else:
                                 break
+                        elif complete_file.exists():
+                            if complete_file.stat().st_size == expected_size:
+                                proceed = False
+                                break
+                            else:
+                                complete_file, partial_file = await self.iterate_filename(complete_file, media, album)
+                                break
                         else:
                             break
                     else:
@@ -335,23 +356,26 @@ class Downloader:
                         partial_file = complete_file.with_suffix(complete_file.suffix + '.part')
                         continue
                 else:
-
-                    iterations = 1
-                    while True:
-                        filename = f"{complete_file.stem} ({iterations}){media.ext}"
-                        iterations += 1
-                        temp_complete_file = (self.download_dir / album / filename)
-                        if not temp_complete_file.exists():
-                            if not await self.SQL_Helper.check_filename(filename):
-                                media.filename = filename
-                                complete_file = (self.download_dir / album / media.filename)
-                                partial_file = complete_file.with_suffix(complete_file.suffix + '.part')
-                                break
+                    complete_file, partial_file = await self.iterate_filename(complete_file, media, album)
                     break
             else:
                 break
         return complete_file, partial_file, proceed
 
+    async def iterate_filename(self, complete_file, media, album):
+        iterations = 1
+        while True:
+            filename = f"{complete_file.stem} ({iterations}){media.ext}"
+            iterations += 1
+            temp_complete_file = (self.download_dir / album / filename)
+            if not temp_complete_file.exists():
+                if not await self.SQL_Helper.check_filename(filename):
+                    media.filename = filename
+                    complete_file = (self.download_dir / album / media.filename)
+                    partial_file = complete_file.with_suffix(complete_file.suffix + '.part')
+                    break
+        return complete_file, partial_file
+
 
 async def download_cascade(args: dict, Cascade: CascadeItem, SQL_Helper: SQLHelper, client: Client,
                            scraper: ScrapeMapper) -> None:
@@ -363,7 +387,7 @@ async def download_cascade(args: dict, Cascade: CascadeItem, SQL_Helper: SQLHelp
     files = Files(overall_file_progress.add_task("[green]Completed", total=total_files),
                   overall_file_progress.add_task("[yellow]Skipped", total=total_files),
                   overall_file_progress.add_task("[red]Failed", total=total_files))
-    with Live(progress_table, refresh_per_second=30):
+    with Live(progress_table, refresh_per_second=args["Progress_Options"]["refresh_rate"]):
         cascade_task = cascade_progress.add_task("[light_salmon3]Domains", progress_type="cascade",
                                                  total=len(Cascade.domains))
 
@@ -400,7 +424,7 @@ async def download_forums(args: dict, Forums: ForumItem, SQL_Helper: SQLHelper,
     files = Files(overall_file_progress.add_task("[green]Completed", total=total_files),
                   overall_file_progress.add_task("[yellow]Skipped", total=total_files),
                   overall_file_progress.add_task("[red]Failed", total=total_files))
-    with Live(progress_table, refresh_per_second=10):
+    with Live(progress_table, refresh_per_second=args["Progress_Options"]["refresh_rate"]):
         forum_task = forum_progress.add_task("[orange3]FORUM THREADS", total=len(Forums.threads))
         for title, Cascade in Forums.threads.items():
             cascade_task = cascade_progress.add_task("[light_salmon3]" + title.upper(), total=len(Cascade.domains))
